@@ -3,13 +3,15 @@ from .resnet import ResNet
 from .segnet import SegNet
 from .unet import UNet
 from .hrnet import HRNet
+from .autoencoder import AutoEncoder
 
 __all__ = [
     'LeNet',
     'ResNet',
     'SegNet',
     'UNet',
-    'HRNet'
+    'HRNet',
+    'AutoEncoder',
 ]
 
 classes = __all__
