@@ -2,27 +2,30 @@ from .octree2vox import octree2voxel, Octree2Voxel
 from .octree2col import octree2col, col2octree
 from .octree_pad import octree_pad, octree_depad
 from .octree_interp import (octree_nearest_pts, octree_linear_pts,
-                            octree_upsample, OctreeInterp, OctreeUpsample)
+                            octree_nearest_upsample, octree_linear_upsample,
+                            OctreeInterp, OctreeUpsample)
 from .octree_pool import (octree_max_pool, OctreeMaxPool,
                           octree_max_unpool, OctreeMaxUnpool,
                           octree_global_pool, OctreeGlobalPool)
 from .octree_conv import OctreeConv, OctreeDeconv
-
+from .octree_norm import OctreeInstanceNorm, OctreeBatchNorm
+from .octree_drop import OctreeDropPath
 
 __all__ = [
     'octree2voxel',
     'octree2col', 'col2octree',
     'octree_pad', 'octree_depad',
     'octree_nearest_pts', 'octree_linear_pts',
-    'octree_upsample',
+    'octree_nearest_upsample', 'octree_linear_upsample',
     'octree_max_pool', 'octree_max_unpool',
     'octree_global_pool',
-
     'Octree2Voxel',
     'OctreeMaxPool', 'OctreeMaxUnpool',
     'OctreeGlobalPool',
     'OctreeConv', 'OctreeDeconv',
     'OctreeInterp', 'OctreeUpsample',
+    'OctreeInstanceNorm', 'OctreeBatchNorm',
+    'OctreeDropPath',
 ]
 
 classes = __all__
