@@ -18,12 +18,21 @@ class Octree:
     device (torch.device or str): Choose from :obj:`cpu` and :obj:`gpu`.
         (default: :obj:`cpu`)
 
+  .. note::
+    The octree data structure requires that if an octree node has children nodes,
+    the number of children nodes is exactly 8, in which some of the nodes are
+    empty and some nodes are non-empty. The properties of an octree, including
+    :obj:`keys`, :obj:`children` and :obj:`neighs`, contain both non-empty and
+    empty nodes, and other properties, including :obj:`features`, :obj:`normals`
+    and :obj:`points`, contain only non-empty nodes.
+
   .. note::
     The point cloud must be in range :obj:`[-1, 1]`.
   '''
 
   def __init__(self, depth: int, full_depth: int = 2, batch_size: int = 1,
                device: Union[torch.device, str] = 'cpu', **kwargs):
+    super().__init__()
     self.depth = depth
     self.full_depth = full_depth
     self.batch_size = batch_size
@@ -44,10 +53,16 @@ class Octree:
     self.normals = [None] * num
     self.points = [None] * num
 
-    # octree node numbers in each octree layers TODO: settle them to 'gpu'?
+    # octree node numbers in each octree layers.
+    # TODO: decide whether to settle them to 'gpu' or not?
     self.nnum = torch.zeros(num, dtype=torch.int32)
     self.nnum_nempty = torch.zeros(num, dtype=torch.int32)
-    # self.nnum_cum = torch.zeros(num, dtype=torch.int32)
+
+    # the following properties are valid after `merge_octrees` and `build_octree`
+    # TODO: make them available after `octree_grow` and `octree_split`
+    batch_size = self.batch_size
+    self.batch_nnum = torch.zeros(num, batch_size, dtype=torch.int32)
+    self.batch_nnum_nempty = torch.zeros(num, batch_size, dtype=torch.int32)
 
     # construct the look up tables for neighborhood searching
     device = self.device
@@ -72,6 +87,55 @@ class Octree:
         '133': torch.tensor([9, 10, 11, 12, 13, 14, 15, 16, 17], device=device),
     }
 
+  def key(self, depth: int, nempty: bool = False):
+    r''' Returns the shuffled key of each octree node.
+
+    Args:
+      depth (int): The depth of the octree.
+      nempty (bool): If True, returns the results of non-empty octree nodes.
+    '''
+
+    key = self.keys[depth]
+    if nempty:
+      mask = self.nempty_mask(depth)
+      key = key[mask]
+    return key
+
+  def xyzb(self, depth: int, nempty: bool = False):
+    r''' Returns the xyz coordinates and the batch indices of each octree node.
+
+    Args:
+      depth (int): The depth of the octree.
+      nempty (bool): If True, returns the results of non-empty octree nodes.
+    '''
+
+    key = self.key(depth, nempty)
+    return key2xyz(key, depth)
+
+  def batch_id(self, depth: int, nempty: bool = False):
+    r''' Returns the batch indices of each octree node.
+
+    Args:
+      depth (int): The depth of the octree.
+      nempty (bool): If True, returns the results of non-empty octree nodes.
+    '''
+
+    batch_id = self.keys[depth] >> 48
+    if nempty:
+      mask = self.nempty_mask(depth)
+      batch_id = batch_id[mask]
+    return batch_id
+
+  def nempty_mask(self, depth: int):
+    r''' Returns a binary mask which indicates whether the cooreponding octree
+    node is empty or not.
+
+    Args:
+      depth (int): The depth of the octree.
+    '''
+
+    return self.children[depth] >= 0
+
   def build_octree(self, point_cloud: Points):
     r''' Builds an octree from a point cloud.
 
@@ -127,6 +191,10 @@ class Octree:
     self.children[d] = children
     self.nnum_nempty[d] = node_key.numel()
 
+    # set the batch_nnum
+    self.batch_nnum[:, 0] = self.nnum
+    self.batch_nnum_nempty[:, 0] = self.nnum_nempty
+
     # average the signal for the last octree layer
     d = self.depth
     points = scatter_add(points, idx, dim=0)  # here points is rescaled in L84
@@ -210,13 +278,11 @@ class Octree:
     self.nnum_nempty[depth] = nnum
 
     # update keys
-    key = self.keys[depth-1]
-    nempty = self.children[depth-1] >= 0
-    key = key[nempty].unsqueeze(1)
+    key = self.key(depth-1, nempty=True)
     batch_id = (key >> 48) << 48
     key = (key & ((1 << 48) - 1)) << 3
     key = key | batch_id
-    key = key + torch.arange(8, device=key.device)
+    key = key.unsqueeze(1) + torch.arange(8, device=key.device)
     self.keys[depth] = key.view(-1)
 
     # update children
@@ -398,6 +464,8 @@ class Octree:
     octree.points = list_to_device(self.points)
     octree.nnum = self.nnum.clone()  # TODO: whether to move nnum to the self.device?
     octree.nnum_nempty = self.nnum_nempty.clone()
+    octree.batch_nnum = self.batch_nnum.clone()
+    octree.batch_nnum_nempty = self.batch_nnum_nempty.clone()
     return octree
 
   def cuda(self):
@@ -437,13 +505,15 @@ def merge_octrees(octrees: List['Octree']):
     torch._assert(condition, 'The check of merge_octrees failed')
 
   # node num
-  nnum = torch.stack(
+  batch_nnum = torch.stack(
       [octrees[i].nnum for i in range(octree.batch_size)], dim=1)
-  nnum_nempty = torch.stack(
+  batch_nnum_nempty = torch.stack(
       [octrees[i].nnum_nempty for i in range(octree.batch_size)], dim=1)
-  octree.nnum = torch.sum(nnum, dim=1)
-  octree.nnum_nempty = torch.sum(nnum_nempty, dim=1)
-  nnum_cum = cumsum(nnum_nempty, dim=1, exclusive=True)
+  octree.nnum = torch.sum(batch_nnum, dim=1)
+  octree.nnum_nempty = torch.sum(batch_nnum_nempty, dim=1)
+  octree.batch_nnum = batch_nnum
+  octree.batch_nnum_nempty = batch_nnum_nempty
+  nnum_cum = cumsum(batch_nnum_nempty, dim=1, exclusive=True)
 
   # merge octre properties
   for d in range(octree.depth+1):
